/**
 * Module to show Recently Viewed Products
 *
 * Copyright (c) 2014 Caroline Schnapp (11heavens.com)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */
Shopify.Products = (function() {

  var config = { 
    howManyToStoreInMemory: Number($('.recently_view_products_wokiee').attr('data-count'))+1
  };

  var cookie = {
    configuration: {
      expires: 90,
      path: '/',
      domain: window.location.hostname
    },
    name: 'shopify_recently_viewed',
    write: function(recentlyViewed) {
      jQuery.cookie(this.name, recentlyViewed.join(' '), this.configuration);
    },
    read: function() {
      var recentlyViewed = [];
      var cookieValue = jQuery.cookie(this.name);
      if (cookieValue && cookieValue !== null) {
        recentlyViewed = cookieValue.split(' ');
      }
      return recentlyViewed;        
    },
    destroy: function() {
      jQuery.cookie(this.name, null, this.configuration);
    },
    remove: function(productHandle) {
      var recentlyViewed = this.read();
      var position = jQuery.inArray(productHandle, recentlyViewed);
      if (position !== -1) {
        recentlyViewed.splice(position, 1);
        this.write(recentlyViewed);
      }       
    }
  };

  return {
    readCookie: function(){
      return cookie.read();
    },
    recordRecentlyViewed: function(params) {

      var params = params || {};

      // Update defaults.
      jQuery.extend(config, params);

      // Read cookie.
      var recentlyViewed = cookie.read();

      // If we are on a product page.
      if (window.location.pathname.indexOf('/products/') !== -1) {

        // What is the product handle on this page.
        var productHandle = $('[data-prpageprhandle]').attr('data-prpageprhandle');
        // In what position is that product in memory.
        var position = jQuery.inArray(productHandle, recentlyViewed);
        // If not in memory.
        if (position === -1) {
          // Add product at the start of the list.
          recentlyViewed.unshift(productHandle);
          // Only keep what we need.
          console.log(config.howManyToStoreInMemory)
          recentlyViewed = recentlyViewed.splice(0, config.howManyToStoreInMemory);
        }
        else {
          // Remove the product and place it at start of list.
          recentlyViewed.splice(position, 1);
          recentlyViewed.unshift(productHandle);              
        }

        // Update cookie.
        cookie.write(recentlyViewed);
      }
    }
  };
})();
/**
 * Copyright (c) 2020 p-themes (https://themeforest.net/item/wokiee-multipurpose-shopify-theme/22559417?s_rank=6)
*/
$(document).ready(function(){
  var _parent = $('.recently_view_products_wokiee');
  if(!_parent.length) return false;
  
  Shopify.Products.recordRecentlyViewed();
  
  var currentproducts = Shopify.Products.readCookie();
  if(currentproducts.length <= 1) return false;
  
  var productHandle = $('[data-prpageprhandle]').attr('data-prpageprhandle');
  var index = currentproducts.indexOf(productHandle);
  if (index !== -1) currentproducts.splice(index, 1);
  
  currentproducts = currentproducts.join('||');

  $.ajax({
    type: "GET",
    url: '/collections/all',
    data: {
      view: 'ajax_recently_viewed',
      sort_by: currentproducts
    },
    cache: false,
    success: function(data){
      _parent.find('.recently_view_products-box').replaceWith($(data));
      _parent.removeClass('hide');
      initImagesSize();
      lazyload();
      sliderInit();
    }
  })
  
  function sliderInit(){
    var slick = $('.tt-recently-products-js'),
        item =  $('.recently_view_products_wokiee').data('item');
    slick.slick({
      dots: false,
      arrows: true,
      infinite: true,
      speed: 300,
      slidesToShow: item || 4,
      slidesToScroll: item || 4,
      adaptiveHeight: true,
      responsive: [
        {
          breakpoint: 1025,
          settings: {
            slidesToShow: 3,
            slidesToScroll: 3
          }
        },
        {
          breakpoint: 791,
          settings: {
            slidesToShow: 2,
            slidesToScroll: 2
          }
        }]
    });
  };
})